abacusai.document_store — AbacusAI documentation

# `abacusai.document_store`

## Module Contents

### Classes

`DocumentStore` | A document store.

class abacusai.document_store.DocumentStore(client, documentStoreId=None, createdAt=None, name=None, documentType=None, documentCount=None, approximateSize=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A document store.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - documentStoreId (str) – A unique string identifier for the document store.

    - createdAt (str) – The timestamp in ISO-8601 format when the document store was created.

    - name (str) – The name of the document store.

    - documentType (str) – The type of documents stored in the document store, as an enumerated string.

    - documentCount (int) – The number of documents in the document store.

    - approximateSize (int) – An approximate count of bytes for all documents stored in the document store. Description: A document store is a repository for storing documents.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict